# Lazy Balika

## Console Logging

Log messages into DB and show them in console.

## DB Logging

> _Log into DB is not working yet. :(_

## Menu

You can create menus for console apps easy.

Add opptions

`LazyBalikaMenu(options)`

## Send Mail

> _Send Mail is not working yet. :(_